pub struct WakfloPlugin {
    pub name: String,
    pub icon: String,
    pub category: String,
    pub language: PluginLanguage,
    pub version: String,
    pub description: String,
    pub documentation: Option<String>,
    pub properties: Option<HashMap<String, Value>>,
}
WakfloPlugin

Connector contract represent an ant schema that takes in operators and actions to be performed on a dataset

Fields

name: String

Name of the the schema

icon: String

Icon based on https://icon-sets.iconify.design/

category: String

Human readable identity of a category

language: PluginLanguage

Version of the plugin

version: String

Version of the plugin

description: String

Description of the the schema

documentation: Option<String>

Name of the the schema

properties: Option<HashMap<String, Value>>