Struct wakflo_common::plugin::WakfloPlugin
source · pub struct WakfloPlugin {
pub name: String,
pub icon: String,
pub category: String,
pub language: PluginLanguage,
pub version: String,
pub description: String,
pub documentation: Option<String>,
pub properties: Option<HashMap<String, Value>>,
}Expand description
WakfloPlugin
Connector contract represent an ant schema that takes in operators and actions to be performed on a dataset
Fields
name: StringName of the the schema
icon: StringIcon based on https://icon-sets.iconify.design/
category: StringHuman readable identity of a category
language: PluginLanguageVersion of the plugin
version: StringVersion of the plugin
description: StringDescription of the the schema
documentation: Option<String>Name of the the schema
properties: Option<HashMap<String, Value>>Trait Implementations
sourceimpl Clone for WakfloPlugin
impl Clone for WakfloPlugin
sourcefn clone(&self) -> WakfloPlugin
fn clone(&self) -> WakfloPlugin
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for WakfloPlugin
impl Debug for WakfloPlugin
sourceimpl Default for WakfloPlugin
impl Default for WakfloPlugin
sourcefn default() -> WakfloPlugin
fn default() -> WakfloPlugin
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for WakfloPlugin
impl<'de> Deserialize<'de> for WakfloPlugin
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq for WakfloPlugin
impl PartialEq for WakfloPlugin
sourcefn eq(&self, other: &WakfloPlugin) -> bool
fn eq(&self, other: &WakfloPlugin) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for WakfloPlugin
impl Serialize for WakfloPlugin
impl Eq for WakfloPlugin
impl StructuralEq for WakfloPlugin
impl StructuralPartialEq for WakfloPlugin